pilas.estudiante.Estudiante

Package pilas :: Module estudiante :: Class Estudiante |
[hide private]
[frames] | no frames]

# Class Estudiante

source code

Known Subclasses:
  - actores.actor.Actor

Componente que permite a los actores aprender habilidades o realizar comportamientos.

Instance Methods | [hide private]
__init__(self) Inicializa el componente. | source code
_adoptar_el_siguiente_comportamiento(self) | source code
actualizar_comportamientos(self) Actualiza la lista de comportamientos | source code
actualizar_habilidades(self) Realiza una actualización sobre todas las habilidades. | source code
agregar_habilidad(self, classname, *k, **w) Agrega una habilidad a la lista de cosas que puede hacer un actor. | source code
aprender(self, classname, *k, **w) Comienza a realizar una habilidad indicada por parametros. | source code
eliminar_comportamientos(self) Elimina todos los comportamientos que tiene que hacer el actor. | source code
eliminar_habilidad(self, classname) Elimina una habilidad asociada a un Actor. | source code
eliminar_habilidades(self) Elimina todas las habilidades asociadas al actor. | source code
hacer(self, comportamiento) Define el comportamiento para el actor de manera inmediata. | source code
hacer_luego(self, comportamiento, repetir_por_siempre=False) Define un nuevo comportamiento para realizar al final. | source code
obtener_habilidad(self, classname) Obtiene la habilidad asociada a un Actor. | source code
tiene_comportamiento(self, classname) Comprueba si el actor tiene el comportamiento indicado. | source code
tiene_habilidad(self, classname) Comprueba si el actor ha aprendido la habilidad indicada. | source code

Method Details | [hide private]

### agregar_habilidad(self, classname, *k, **w) | source code
Agrega una habilidad a la lista de cosas que puede hacer un actor. :param classname: Referencia a la clase que representa la habilidad.

### aprender(self, classname, *k, **w) | source code
Comienza a realizar una habilidad indicada por parametros. :param classname: Referencia a la clase que representa la habilidad.

### eliminar_habilidad(self, classname) | source code
Elimina una habilidad asociada a un Actor. :param classname: Referencia a la clase que representa la habilidad.

### hacer(self, comportamiento) | source code
Define el comportamiento para el actor de manera inmediata. :param comportamiento: Referencia al comportamiento a realizar.

### hacer_luego(self, comportamiento, repetir_por_siempre=False) | source code
Define un nuevo comportamiento para realizar al final. Los actores pueden tener una cadena de comportamientos, este metodo agrega el comportamiento al final de la cadena. :param comportamiento: Referencia al comportamiento. :param repetir_por_siempre: Si el comportamiento se volverá a ejecutar luego de terminar.

### obtener_habilidad(self, classname) | source code
Obtiene la habilidad asociada a un Actor. :param classname: Referencia a la clase que representa la habilidad. :return: Devuelve None si no se encontró.

### tiene_comportamiento(self, classname) | source code
Comprueba si el actor tiene el comportamiento indicado. :param classname: Referencia a la clase que representa el comportamiento.

### tiene_habilidad(self, classname) | source code
Comprueba si el actor ha aprendido la habilidad indicada. :param classname: Referencia a la clase que representa la habilidad.